pub fn decode_stream_line(
line: &[u8],
limits: &Limits,
) -> Result<StreamFrame, NetbatError>Expand description
Decode one NETBAT/2 streaming line frame.
Errors
Returns NetbatError when the frame is malformed or exceeds limits.
pub fn decode_stream_line(
line: &[u8],
limits: &Limits,
) -> Result<StreamFrame, NetbatError>Decode one NETBAT/2 streaming line frame.
Returns NetbatError when the frame is malformed or exceeds limits.